[![Build Status](https://travis-ci.org/solos/musca.png?branch=master)](https://travis-ci.org/solos/musca)
[![Downloads](https://pypip.in/d/musca/badge.png)](https://pypi.python.org/pypi/musca)
[![Version](https://img.shields.io/pypi/v/musca.svg)](https://img.shields.io/pypi/v/musca.svg)
# musca

#About

Another way to control musca.

#Install

    pip install musca


#Demo


   [<img src="http://ww2.sinaimg.cn/large/61f33e51tw1egz042lcspg20zk0m8jvw.gif">](Demo)
